"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateProps = generateProps;
exports["default"] = void 0;

var _errors = require("../errors");

function generateProps(propList) {
  var propTypesToReturn = {};
  var defaultPropsToReturn = {};
  var errors = []; // ensure propList is an object

  if (!isObject(propList)) {
    errors.push(_errors.ErrorList.notAnObject);
  }

  if (errors.length === 0) {
    // loop through and get all properties
    var _iterateObject = iterateObject(propList);

    propTypesToReturn = _iterateObject.propTypesToReturn;
    defaultPropsToReturn = _iterateObject.defaultPropsToReturn;
  }

  return {
    propTypesToReturn: propTypesToReturn,
    defaultPropsToReturn: defaultPropsToReturn,
    errors: errors
  };
}

function iterateObject(obj) {
  var toReturn = {
    propTypesToReturn: {},
    defaultPropsToReturn: {}
  };
  var keys = Object.keys(obj);
  keys.forEach(function (key) {
    var currentVal = obj[key];
    var currentValPropType;
    var currentValDefaultProp;

    if (isObject(currentVal)) {
      var iteratedData = iterateObject(currentVal);
      currentValPropType = iteratedData.propTypesToReturn;
      currentValDefaultProp = iteratedData.defaultPropsToReturn;
    } else if (isArray(currentVal)) {
      if (typeof currentVal[0] !== "undefined") {
        // default prop
        currentValDefaultProp = currentVal[0];
      }

      if (typeof currentVal[1] !== "undefined") {
        // propType
        currentValPropType = currentVal[1];
      }
    }

    if (typeof currentValPropType !== "undefined") {
      toReturn.propTypesToReturn[key] = currentValPropType;
    }

    if (typeof currentValDefaultProp !== "undefined") {
      toReturn.defaultPropsToReturn[key] = currentValDefaultProp;
    }
  });
  return toReturn;
}

function isArray(toCheck) {
  return Array.isArray(toCheck);
}

function isObject(toCheck) {
  if (typeof toCheck === "object" && !isArray(toCheck)) {
    return true;
  }

  return false;
}

var _default = null;
exports["default"] = _default;